aboutsummaryrefslogtreecommitdiffstats
path: root/Software
diff options
context:
space:
mode:
authorRoy Ben Shabat <Roy.mail.net@gmail.com>2025-03-26 16:23:39 +0200
committerRoy Ben Shabat <Roy.mail.net@gmail.com>2025-03-26 16:23:39 +0200
commitaf33c539cc7034dc334fd25dc743e36d787c9cbf (patch)
tree8b6e146250703916e2dbef94ac8b538870269bd3 /Software
parente960eb18572608372adb4a34f43c4a7dcdcd118b (diff)
downloadTango-af33c539cc7034dc334fd25dc743e36d787c9cbf.tar.gz
Tango-af33c539cc7034dc334fd25dc743e36d787c9cbf.zip
Updated PMR with new events.
Diffstat (limited to 'Software')
-rw-r--r--Software/PMR/Messages/Diagnostics/EventType.proto57
1 files changed, 45 insertions, 12 deletions
diff --git a/Software/PMR/Messages/Diagnostics/EventType.proto b/Software/PMR/Messages/Diagnostics/EventType.proto
index 9355cce8d..32031039f 100644
--- a/Software/PMR/Messages/Diagnostics/EventType.proto
+++ b/Software/PMR/Messages/Diagnostics/EventType.proto
@@ -142,7 +142,7 @@ enum EventType
//Communication failure. Cannot execute job (Group = GeneralHardware, Category = Error)
I2C4_COMMUNICATION_FAILURE = 2026;
- //Communication failure. Cannot execute job (Group = Transport, Category = Warning)
+ //Communication failure. Cannot execute job (Group = GeneralHardware, Category = Warning)
I2C_COMMUNICATION_FAILURE = 2027;
//Thread break. Cannot execute job (Group = ThreadFeedingSystem, Category = Error)
@@ -1840,6 +1840,18 @@ enum EventType
//Tunnel suction flow too low. Cannot execute job (Group = DyeingHead, Category = Error)
E_TUNNEL_SUCTION_FLOW_TOO_LOW = 111008;
+ //Dryer push flow too high. Cannot execute job (Group = Dryer, Category = Error)
+ E_DRYER_PUSH_FLOW_TOO_HIGH = 111009;
+
+ //Dryer suction flow too high. Cannot execute job (Group = Dryer, Category = Error)
+ E_DRYER_SUCTION_FLOW_TOO_HIGH = 111010;
+
+ //Tunnel push flow too high. Cannot execute job (Group = DyeingHead, Category = Error)
+ E_TUNNEL_PUSH_FLOW_TOO_HIGH = 111011;
+
+ //Tunnel suction flow too high. Cannot execute job (Group = DyeingHead, Category = Error)
+ E_TUNNEL_SUCTION_FLOW_TOO_HIGH = 111012;
+
//Pressure in @ ink line too high. Cannot execute job (Group = InkDeliverySystem, Category = Error)
E_INK_LINE_1_PRESSURE_TOO_HIGH = 112000;
@@ -1975,34 +1987,34 @@ enum EventType
//The @ tank level is low (Group = InkFillingSystem, Category = Warning)
E_INK_LINE_10_MID_TANK_LOW_LEVEL = 112044;
//Failed to fill @ tank. Cannot execute job (Group = InkFillingSystem, Category = Error)
E_INK_LINE_1_MID_TANK_FILL_TIMEOUT = 112045;
//Failed to fill @ tank. Cannot execute job (Group = InkFillingSystem, Category = Error)
E_INK_LINE_2_MID_TANK_FILL_TIMEOUT = 112046;
//Failed to fill @ tank. Cannot execute job (Group = InkFillingSystem, Category = Error)
E_INK_LINE_3_MID_TANK_FILL_TIMEOUT = 112047;
//Failed to fill @ tank. Cannot execute job (Group = InkFillingSystem, Category = Error)
E_INK_LINE_4_MID_TANK_FILL_TIMEOUT = 112048;
//Failed to fill @ tank. Cannot execute job (Group = InkFillingSystem, Category = Error)
E_INK_LINE_5_MID_TANK_FILL_TIMEOUT = 112049;
//Failed to fill @ tank. Cannot execute job (Group = InkFillingSystem, Category = Error)
E_INK_LINE_6_MID_TANK_FILL_TIMEOUT = 112050;
//Failed to fill @ tank. Cannot execute job (Group = InkFillingSystem, Category = Error)
E_INK_LINE_7_MID_TANK_FILL_TIMEOUT = 112051;
//Failed to fill @ tank. Cannot execute job (Group = InkFillingSystem, Category = Error)
E_INK_LINE_8_MID_TANK_FILL_TIMEOUT = 112052;
//Failed to fill @ tank. Cannot execute job (Group = InkFillingSystem, Category = Error)
E_INK_LINE_9_MID_TANK_FILL_TIMEOUT = 112053;
//Failed to fill @ tank. Cannot execute job (Group = InkFillingSystem, Category = Error)
E_INK_LINE_10_MID_TANK_FILL_TIMEOUT = 112054;
//Malfunction in @ tank. Cannot execute job (Group = InkFillingSystem, Category = Error)
@@ -2056,7 +2068,7 @@ enum EventType
//The @ tank level is low (Group = InkFillingSystem, Category = Warning)
E_INK_LINE_11_MID_TANK_LOW_LEVEL = 112071;
//Failed to fill @ tank. Cannot execute job (Group = InkFillingSystem, Category = Error)
E_INK_LINE_11_MID_TANK_FILL_TIMEOUT = 112072;
//Malfunction in @ tank. Cannot execute job (Group = InkFillingSystem, Category = Error)
@@ -2095,4 +2107,25 @@ enum EventType
//The @ tank is empty. Cannot execute job (Group = InkFillingSystem, Category = Error)
E_INK_LINE_11_MID_TANK_EMPTY = 112084;
+ //Lubricant Jerrycan is empty (Group = Mixer, Category = Error)
+ E_LUBRICANT_JERRYCAN_IS_EMPTY = 112085;
+
+ //Lubricant jerrycan is not present. Cannot execute job (Group = Mixer, Category = Error)
+ E_LUBRICANT_JERRYCAN_NOT_PRESENT = 112086;
+
+ //Waste jerrycan is not present. Cannot execute job (Group = WasteHandlingSystem, Category = Error)
+ E_WASTE_JERRYCAN_NOT_PRESENT = 113000;
+
+ //Waste jerrycan is full. Cannot execute job (Group = WasteHandlingSystem, Category = Error)
+ E_WASTE_JERRYCAN_IS_FULL = 113001;
+
+ //Waste jerrycan and sub-tanks are full. Cannot execute job (Group = WasteHandlingSystem, Category = Error)
+ E_WASTE_JERRYCAN_AND_SUB_TANKS_ARE_FULL = 113002;
+
+ //No draining from IDU-Chimney sub-tank. Cannot execute job (Group = WasteHandlingSystem, Category = Error)
+ E_NO_DRAINING_FROM_IDU_CHIMNEY_SUB_TANK = 113003;
+
+ //No draining from IFS-Dryer sub-tank. Cannot execute job (Group = WasteHandlingSystem, Category = Error)
+ E_NO_DRAINING_FROM_IFS_DRYER_SUB_TANK = 113004;
+
}
@@ -1975,34 +1987,34 @@ enum EventType
//The @ tank level is low (Group = InkFillingSystem, Category = Warning)
E_INK_LINE_10_MID_TANK_LOW_LEVEL = 112044;
- //Failed to fill @ tank. Cannot execute job (Group = InkFillingSystem, Category = Error)
+ //Cannot fill @ tank. Replace @ jerrycan to start new job (Group = InkFillingSystem, Category = Error)
E_INK_LINE_1_MID_TANK_FILL_TIMEOUT = 112045;
@@ -1975,34 +1987,34 @@ enum EventType
E_INK_LINE_1_MID_TANK_FILL_TIMEOUT = 112045;
- //Failed to fill @ tank. Cannot execute job (Group = InkFillingSystem, Category = Error)
+ //Cannot fill @ tank. Replace @ jerrycan to start new job (Group = InkFillingSystem, Category = Error)
E_INK_LINE_2_MID_TANK_FILL_TIMEOUT = 112046;
@@ -1975,34 +1987,34 @@ enum EventType
E_INK_LINE_2_MID_TANK_FILL_TIMEOUT = 112046;
- //Failed to fill @ tank. Cannot execute job (Group = InkFillingSystem, Category = Error)
+ //Cannot fill @ tank. Replace @ jerrycan to start new job (Group = InkFillingSystem, Category = Error)
E_INK_LINE_3_MID_TANK_FILL_TIMEOUT = 112047;
@@ -1975,34 +1987,34 @@ enum EventType
E_INK_LINE_3_MID_TANK_FILL_TIMEOUT = 112047;
- //Failed to fill @ tank. Cannot execute job (Group = InkFillingSystem, Category = Error)
+ //Cannot fill @ tank. Replace @ jerrycan to start new job (Group = InkFillingSystem, Category = Error)
E_INK_LINE_4_MID_TANK_FILL_TIMEOUT = 112048;
@@ -1975,34 +1987,34 @@ enum EventType
E_INK_LINE_4_MID_TANK_FILL_TIMEOUT = 112048;
- //Failed to fill @ tank. Cannot execute job (Group = InkFillingSystem, Category = Error)
+ //Cannot fill @ tank. Replace @ jerrycan to start new job (Group = InkFillingSystem, Category = Error)
E_INK_LINE_5_MID_TANK_FILL_TIMEOUT = 112049;
@@ -1975,34 +1987,34 @@ enum EventType
E_INK_LINE_5_MID_TANK_FILL_TIMEOUT = 112049;
- //Failed to fill @ tank. Cannot execute job (Group = InkFillingSystem, Category = Error)
+ //Cannot fill @ tank. Replace @ jerrycan to start new job (Group = InkFillingSystem, Category = Error)
E_INK_LINE_6_MID_TANK_FILL_TIMEOUT = 112050;
@@ -1975,34 +1987,34 @@ enum EventType
E_INK_LINE_6_MID_TANK_FILL_TIMEOUT = 112050;
- //Failed to fill @ tank. Cannot execute job (Group = InkFillingSystem, Category = Error)
+ //Cannot fill @ tank. Replace @ jerrycan to start new job (Group = InkFillingSystem, Category = Error)
E_INK_LINE_7_MID_TANK_FILL_TIMEOUT = 112051;
@@ -1975,34 +1987,34 @@ enum EventType
E_INK_LINE_7_MID_TANK_FILL_TIMEOUT = 112051;
- //Failed to fill @ tank. Cannot execute job (Group = InkFillingSystem, Category = Error)
+ //Cannot fill @ tank. Replace @ jerrycan to start new job (Group = InkFillingSystem, Category = Error)
E_INK_LINE_8_MID_TANK_FILL_TIMEOUT = 112052;
@@ -1975,34 +1987,34 @@ enum EventType
E_INK_LINE_8_MID_TANK_FILL_TIMEOUT = 112052;
- //Failed to fill @ tank. Cannot execute job (Group = InkFillingSystem, Category = Error)
+ //Cannot fill @ tank. Replace @ jerrycan to start new job (Group = InkFillingSystem, Category = Error)
E_INK_LINE_9_MID_TANK_FILL_TIMEOUT = 112053;
@@ -1975,34 +1987,34 @@ enum EventType
E_INK_LINE_9_MID_TANK_FILL_TIMEOUT = 112053;
- //Failed to fill @ tank. Cannot execute job (Group = InkFillingSystem, Category = Error)
+ //Cannot fill @ tank. Replace @ jerrycan to start new job (Group = InkFillingSystem, Category = Error)
E_INK_LINE_10_MID_TANK_FILL_TIMEOUT = 112054;
//Malfunction in @ tank. Cannot execute job (Group = InkFillingSystem, Category = Error)
@@ -2056,7 +2068,7 @@ enum EventType
//The @ tank level is low (Group = InkFillingSystem, Category = Warning)
E_INK_LINE_11_MID_TANK_LOW_LEVEL = 112071;
- //Failed to fill @ tank. Cannot execute job (Group = InkFillingSystem, Category = Error)
+ //Cannot fill @ tank. Replace @ jerrycan to start new job (Group = InkFillingSystem, Category = Error)
E_INK_LINE_11_MID_TANK_FILL_TIMEOUT = 112072;
//Malfunction in @ tank. Cannot execute job (Group = InkFillingSystem, Category = Error)